@@ -52,13 +52,13 @@ class BillPaymentLine(QuickbooksBaseObject):
 @python_2_unicode_compatible
 class BillPayment(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTxnMixin):
     """
-    QBO definition: A BillPayment entity represents the financial transaction of payment of bills that the
-    business owner receives from a vendor for goods or services purchased from the vendor. QuickBooks Online
-    supports bill payments through a credit card or a checking account.
-    BillPayment.TotalAmt is the total amount associated with this payment. This includes the total of all the
-    payments from the payment line details. If TotalAmt is greater than the total on the lines being paid,
-    the overpayment is treated as a credit and exposed as such on the QuickBooks UI. The total amount
-    cannot be negative.
+    QBO definition: A BillPayment entity represents the financial transaction of payment
+    of bills that the business owner receives from a vendor for goods or services purchased
+    from the vendor. QuickBooks Online supports bill payments through a credit card or a
+    checking account. BillPayment.TotalAmt is the total amount associated with this payment.
+    This includes the total of all the payments from the payment line details. If TotalAmt is
+    greater than the total on the lines being paid, the overpayment is treated as a credit and
+    exposed as such on the QuickBooks UI. The total amount cannot be negative.
     """
 
     class_dict = {
@@ -82,7 +82,6 @@ class BillPayment(QuickbooksManagedObject, QuickbooksTransactionEntity, LinkedTx
         self.TotalAmt = 0
         self.PrivateNote = ""
         self.DocNumber = ""
-        #self.ProcessBillPayment = False
 
         self.VendorRef = None
         self.CheckPayment = None
